@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Rinci::AddPrereqs;
 
-our $DATE = '2015-04-02'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-12-25'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,6 +48,8 @@ sub _add_prereq {
 }
 
 sub _add_prereqs_from_func_meta {
+    require Perinci::Sub::Util::PropertyModule;
+
     my ($self, $meta, $is_cli) = @_;
 
     $meta = normalize_function_metadata($meta);
@@ -92,6 +94,11 @@ sub _add_prereqs_from_func_meta {
         }
     }
 
+    # property modules
+    {
+        my $mods = Perinci::Sub::Util::PropertyModule::get_required_property_modules($meta);
+        $self->_add_prereq($_ => 0) for @$mods;
+    }
 }
 
 sub munge_file {
@@ -171,7 +178,7 @@ Dist::Zilla::Plugin::Rinci::AddPrereqs - Add prerequisites from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.06 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2015-04-02.
+This document describes version 0.07 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2015-12-25.
 
 =head1 SYNOPSIS
 
